@@ -7,12 +7,14 @@ function ScormStudioXBlock(runtime, element) {
         var file_data = $(element).find('#scorm_file').prop('files')[0];
         var display_name = $(element).find('input[name=display_name]').val();
         var has_score = $(element).find('select[name=has_score]').val();
+        var weight = $(element).find('input[name=weight]').val();
         var width = $(element).find('input[name=width]').val();
         var height = $(element).find('input[name=height]').val();
 
         form_data.append('file', file_data);
         form_data.append('display_name', display_name);
         form_data.append('has_score', has_score);
+        form_data.append('weight', weight);
         form_data.append('width', width);
         form_data.append('height', height);
         runtime.notify('save', {
